resource "kubernetes_manifest" "kafka_user" {
  manifest = {
    "apiVersion" = "kafka.strimzi.io/v1beta2"
    "kind"       = "KafkaUser"
    "metadata"   = {
      "labels" = {
        "strimzi.io/cluster" = var.cluster-name
      }
      "name"      = "kafka-user"
      "namespace" = var.namespace
    }
    "spec" = {
      "authentication" = {
        "type" = var.user-auth-type
      }
      "authorization" = {
        "acls" = [
          {
            "host"       = "*"
            "operations" = [
              "Describe",
              "Write"
            ]
            "resource" = {
              "name"        = "dev.emitter."
              "type"        = "topic"
              "patternType" = "prefix"
            }
          },
          {
            "host"       = "*"
            "operations" = [
              "Describe",
              "Read"
            ]
            "resource" = {
              "name"        = "dev.receiver."
              "type"        = "topic"
              "patternType" = "prefix"
            }
          },
          {
            "host"       = "*"
            "operations" = [
              "Describe"
            ]
            "resource" = {
              "name"        = "__transaction_state"
              "type"        = "topic"
              "patternType" = "literal"
            }
          },
          {
            "host"       = "*"
            "operations" = [
              "Describe",
              "Read"
            ]
            "resource" = {
              "type"        = "group"
              "name"        = "some-consumer"
              "patternType" = "literal"
            }
          },
          {
            "host"       = "*"
            "operations" = ["Describe", "Write"],
            "resource"   = {
              "type"        = "transactionalId",
              "name"        = "txn_producer-"
              "patternType" = "prefix"
            }
          }
        ]
        "type" = "simple"
      }
    }
  }
}
